==> ejc-probuilddiary-impl-3.0.0-20220923.051842-54-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonInformationEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程资料归档及会议情况（资料员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_information")
public class PersonInformationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="inform_mold_id")
    private Long informMoldId; // 工作类型id
    @TableField(value="inform_mold_name")
    private String informMoldName; // 工作类型名称
    @TableField(value="inform_mold_code")
    private String informMoldCode; // 工作类型编码
    @TableField(value="information_memo")
    private String informationMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getInformMoldId() {
        return informMoldId;
    }

    public void setInformMoldId(Long informMoldId) {
        this.informMoldId = informMoldId;
    }
    public String getInformMoldName() {
        return informMoldName;
    }

    public void setInformMoldName(String informMoldName) {
        this.informMoldName = informMoldName;
    }
    public String getInformMoldCode() {
        return informMoldCode;
    }

    public void setInformMoldCode(String informMoldCode) {
        this.informMoldCode = informMoldCode;
    }
    public String getInformationMemo() {
        return informationMemo;
    }

    public void setInformationMemo(String informationMemo) {
        this.informationMemo = informationMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20220928.093642-91-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonInformationEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程资料归档及会议情况（资料员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_information")
public class PersonInformationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="inform_mold_id")
    private Long informMoldId; // 工程类型id
    @TableField(value="inform_mold_name")
    private String informMoldName; // 工作类型名称
    @TableField(value="inform_mold_code")
    private String informMoldCode; // 工作类型编码
    @TableField(value="information_memo")
    private String informationMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getInformMoldId() {
        return informMoldId;
    }

    public void setInformMoldId(Long informMoldId) {
        this.informMoldId = informMoldId;
    }
    public String getInformMoldName() {
        return informMoldName;
    }

    public void setInformMoldName(String informMoldName) {
        this.informMoldName = informMoldName;
    }
    public String getInformMoldCode() {
        return informMoldCode;
    }

    public void setInformMoldCode(String informMoldCode) {
        this.informMoldCode = informMoldCode;
    }
    public String getInformationMemo() {
        return informationMemo;
    }

    public void setInformationMemo(String informationMemo) {
        this.informationMemo = informationMemo;
    }
    
}
